package scalapi.jdk.concurrent

import scala.concurrent.Future
import scala.concurrent.Await.result
import scala.concurrent.duration._

/**
 * Helper methods for [[scala.concurrent.Future]].
 */
object Futures {

  /**
   * Converts [[scala.concurrent.Future]] into its value. This method is blocking.
   *
   * @param future [[scala.concurrent.Future]] to converted
   * @param atMost specifies how low method will block until exception is thrown (default is 5 seconds)
   * @tparam T type of [[scala.concurrent.Future]] value
   * @return value of the [[scala.concurrent.Future]]
   */
  def futureToValue[T](future: Future[Any])(implicit atMost: Duration = 5.seconds): T =
    result(future, atMost).asInstanceOf[T]

}
